import React from 'react';
import { render, screen } from '@testing-library/react';
import userEvent from '@testing-library/user-event';
import NsBrandCard from '../NsBrandCard';

describe('NsBrandCard component', () => {
    const props = {
        title: 'ageLOC LumiSpa',
        backgroundImageUrl: 'https://media.nuskin.com/m/3604b5202b0b64c6/webimage-brand-lumispa-optweb.png',
        brandImageUrl: 'https://media.nuskin.com/m/2571a0407433a6e8/webimage-brand-lumispa.png',
        button: true,
    };

    it('1. renders with correct content and styles', () => {
        render(<NsBrandCard {...props} />);

        const brandCard = screen.getByTestId('brand-card');
        expect(brandCard).toBeInTheDocument();

        const brandTitle = screen.getByText('ageLOC LumiSpa');
        expect(brandTitle).toBeInTheDocument();

        const addToCartButton = screen.getByText('Add to Cart');
        expect(addToCartButton).toBeInTheDocument();
    });

    it('2. does not render brand title when title is not provided', () => {
        const { container } = render(<NsBrandCard {...{ ...props, title: undefined }} />);

        const brandTitle = container.querySelector('.brand-title');
        expect(brandTitle).toBeNull();
    });

    it('3. renders with "Add to Cart" button when button prop is true', () => {
        render(<NsBrandCard {...props} />);

        const addToCartButton = screen.getByText('Add to Cart');
        expect(addToCartButton).toBeInTheDocument();
    });

    it('4. does not render button when button prop is false', () => {
        const { container } = render(<NsBrandCard {...{ ...props, button: false }} />);

        const addToCartButton = container.querySelector('.cta');
        expect(addToCartButton).toBeNull();
    });

    it.skip('5. calls onClick when the "Add to Cart" button is clicked', () => {
        const onClickMock = jest.fn();
        render(<NsBrandCard {...props} onClick={onClickMock} />);

        const addToCartButton = screen.getByText('Add to Cart');
        userEvent.click(addToCartButton);

        expect(onClickMock).toHaveBeenCalled();
    });

    it('6. applies hover styles on mouseover', () => {
        render(<NsBrandCard {...props} />);

        const brandCard = screen.getByTestId('brand-card');
        userEvent.hover(brandCard);

        const brandTitle = screen.getByText('ageLOC LumiSpa');
        expect(brandTitle).toHaveStyle('opacity: 0.7');
    });

    it('7. renders with correct styles when size is "small"', () => {
        const { container } = render(<NsBrandCard {...props} size="small" />);

        const cardContainer = container.firstChild;
        const nsBgCardElement = cardContainer?.firstChild;
        expect(cardContainer).toHaveStyle(`
          width: 165px;
        `);
        expect(nsBgCardElement).toHaveStyle(`
          width: 165px;
          height: 180px;
        `);
    });

    it('8. renders with correct styles when size is "large"', () => {
        render(<NsBrandCard {...props} size="large" />);
        const cardContainer = screen.getByTestId('brand-card') as HTMLElement;
        const computedStyles = window.getComputedStyle(cardContainer);

        expect(computedStyles.width).toBe('190px');
    });

    it('9. renders with default styles when size is not provided', () => {
        render(<NsBrandCard {...props} />);
        const cardContainer = screen.getByTestId('brand-card') as HTMLElement;
        const computedStyles = window.getComputedStyle(cardContainer);

        expect(computedStyles.width).toBe('190px');
    });
});
